@@ -1,27 +1,13 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1997 Matthias Kalle Dalheimer (kalle@kde.org)
-    Copyright (C) 1998, 1999, 2000 Waldo Bastian <bastian@kde.org>
+/*  This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997 Matthias Kalle Dalheimer <kalle@kde.org>
+    SPDX-FileCopyrightText: 1998, 1999, 2000 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kauthorized.h"
 
 #include <QDir>
-#include <QRegExp>
 #include <QList>
 #include <QUrl>
 
@@ -258,7 +244,8 @@ QStringList KAuthorized::authorizeControlModules(const QStringList &menuIds)
     return result;
 }
 
-static void initUrlActionRestrictions()
+// Exported for unittests (e.g. in KIO, we're missing tests for this in kconfig)
+KCONFIGCORE_EXPORT void loadUrlActionRestrictions(const KConfigGroup &cg)
 {
     MY_D
     const QString Any;
@@ -304,7 +291,6 @@ static void initUrlActionRestrictions()
     d->urlActionRestrictions.append(
         URLActionRule("redirect", QStringLiteral("about"), Any, Any, Any, Any, Any, true));
 
-    KConfigGroup cg(KSharedConfig::openConfig(), "KDE URL Restrictions");
     int count = cg.readEntry("rule_count", 0);
     QString keyFormat = QStringLiteral("rule_%1");
     for (int i = 1; i <= count; i++) {
@@ -382,7 +368,8 @@ KCONFIGCORE_EXPORT bool authorizeUrlActionInternal(const QString &action, const
 
     bool result = false;
     if (d->urlActionRestrictions.isEmpty()) {
-        initUrlActionRestrictions();
+        KConfigGroup cg(KSharedConfig::openConfig(), "KDE URL Restrictions");
+        loadUrlActionRestrictions(cg);
     }
 
     QUrl baseURL(_baseURL);
